/*
 *
 *
 *    MotorPins.h
 *
 *    AutoCap Arduino Firmware
 *    Version 1.5
 *
 *    This software is intended for use with the AutoCap software core,
 *    to auto-tune a loop.  This version of the firmware provides basic
 *    motor control, under control of the core, via the Arduino's host
 *    serial link.
 *
 *    License: GNU General Public License Version 3.0.
 *    
 *    Copyright (C) 2014-2016 by Matthew K. Roberts, KK5JY. All rights reserved.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *    
 *    This program is distributed in the hope that it will be useful, but
 *    WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    General Public License for more details.
 *    
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see: http://www.gnu.org/licenses/
 *    
 *
 */

#ifndef AUTOCAP_MOTORPINS_H
#define AUTOCAP_MOTORPINS_H

//
//  DC Motor I/O pin definitions
//
class MotorPins {
	public:
		// PWM "analog" output; actually a pulsed logic output
		uint8_t PWM;
		// brake enable, digital output
		uint8_t Brake;
		// current sense, analog input
		uint8_t Current;
		// direction control, digital output
		uint8_t Polarity;
		// UP output
		uint8_t Up;
		// DOWN output
		uint8_t Down;
		// PORT SELECTED output
		uint8_t LED;
		// assert PWM when braked; this is independent of the brake line,
		//    which may or may not be needed for this to cause effective braking
		bool BrakePWM;

	public:
		// constructor - store pin assignments
		MotorPins(uint8_t pwm, uint8_t bk, uint8_t cur, uint8_t pol, uint8_t up, uint8_t dn, uint8_t led, bool brakePWM) {
			PWM = pwm;
			Brake = bk;
			Current = cur;
			Polarity = pol;
			Up = up;
			Down = dn;
			LED = led;
			BrakePWM = brakePWM;
		}
};

#endif // AUTOCAP_MOTORPINS_H
